pub struct Highlight<'a> { /* private fields */ }Expand description
Represent a highlight action, represented by a query and a tag to show how to visualize it.
Implementations
Sourceimpl<'a> Highlight<'a>
impl<'a> Highlight<'a>
pub fn with_tag(self, tag: Tag<'a>) -> Self
pub fn new(var: &'a str) -> Self
pub fn with_label(self, label: &'a str) -> Self
Sourcepub fn get_tag(&self, annotation: &ResultItem<'a, Annotation>) -> Cow<'a, str>
pub fn get_tag(&self, annotation: &ResultItem<'a, Annotation>) -> Cow<'a, str>
Serializes the tag to string, given an annotation