pub enum Column {
}Expand description
Represents a column in TSV output or input
Variants
SeqNr
Sequence number, usually a row number but sometimes multiple rows may share the same number if hierarchical relations are expressed
VarName
Variable name, as used in a STAMQL query
Type
Type of the result on this row
Id
ID of this result on this row
Annotation
ID of the annotation
TextResource
ID of the text resource
AnnotationData
ID of the annotation data
AnnotationDataSet
ID of the annotation dataset
Offset
Offset in unicode points (begin-end), 0 indexed, end non-inclusive.
BeginOffset
Begin offset in unicode points, 0 indexed.
EndOffset
End offset in unicode points, 0 indexed, non-inclusive.
Utf8Offset
BeginUtf8Offset
Begin offset in bytes (UTF-8 encoding), 0 indexed
EndUtf8Offset
End offset in bytes (UTF-8 encoding), 0 indexed, non-inclusive
DataKey
ID of the data key
DataValue
Value
Text
The text
TextSelection
The text selection is a combination of TextResource and Offset, seperated by a ’#`
Ignore
Ignore this column
Custom
Custom data column, represents the value for the given set and datakey.
Implementations